@@ -18,8 +18,8 @@ import os
 import shutil
 import stat
 import tempfile
+from unittest import mock
 
-import mock
 from oslo_concurrency import processutils
 from oslo_config import cfg
 from oslo_serialization import base64
@@ -800,58 +800,6 @@ class DestroyMetaDataTestCase(base.IronicLibTestCase):
         disk_utils.destroy_disk_metadata(self.dev, self.node_uuid)
         mock_exec.assert_has_calls(expected_call)
 
-    def test_destroy_disk_metadata_ebr(self, mock_exec):
-        expected_calls = [mock.call('wipefs', '--force', '--all', 'fake-dev',
-                                    run_as_root=True,
-                                    use_standard_locale=True),
-                          mock.call('blockdev', '--getsz', 'fake-dev',
-                                    check_exit_code=[0],
-                                    run_as_root=True),
-                          mock.call('dd', 'bs=512', 'if=/dev/zero',
-                                    'of=fake-dev', 'count=2',
-                                    run_as_root=True,
-                                    use_standard_locale=True),
-                          mock.call('sgdisk', '-Z', 'fake-dev',
-                                    run_as_root=True,
-                                    use_standard_locale=True)]
-        mock_exec.side_effect = iter([
-            (None, None),
-            ('2\n', None),  # an EBR is 2 sectors
-            (None, None),
-            (None, None),
-            (None, None),
-            (None, None)])
-        disk_utils.destroy_disk_metadata(self.dev, self.node_uuid)
-        mock_exec.assert_has_calls(expected_calls)
-
-    def test_destroy_disk_metadata_tiny_partition(self, mock_exec):
-        expected_calls = [mock.call('wipefs', '--force', '--all', 'fake-dev',
-                                    run_as_root=True,
-                                    use_standard_locale=True),
-                          mock.call('blockdev', '--getsz', 'fake-dev',
-                                    check_exit_code=[0],
-                                    run_as_root=True),
-                          mock.call('dd', 'bs=512', 'if=/dev/zero',
-                                    'of=fake-dev', 'count=33',
-                                    run_as_root=True,
-                                    use_standard_locale=True),
-                          mock.call('dd', 'bs=512', 'if=/dev/zero',
-                                    'of=fake-dev', 'count=33', 'seek=9',
-                                    run_as_root=True,
-                                    use_standard_locale=True),
-                          mock.call('sgdisk', '-Z', 'fake-dev',
-                                    run_as_root=True,
-                                    use_standard_locale=True)]
-        mock_exec.side_effect = iter([
-            (None, None),
-            ('42\n', None),
-            (None, None),
-            (None, None),
-            (None, None),
-            (None, None)])
-        disk_utils.destroy_disk_metadata(self.dev, self.node_uuid)
-        mock_exec.assert_has_calls(expected_calls)
-
 
 @mock.patch.object(utils, 'execute', autospec=True)
 class GetDeviceBlockSizeTestCase(base.IronicLibTestCase):
@@ -1149,29 +1097,6 @@ class OtherFunctionTestCase(base.IronicLibTestCase):
             convert_call,
         ])
 
-    @mock.patch.object(utils, 'execute', autospec=True)
-    def test_convert_image_retries_alternate_error(self, execute_mock):
-        ret_err = 'Failed to allocate memory: Cannot allocate memory\n'
-        execute_mock.side_effect = [
-            processutils.ProcessExecutionError(stderr=ret_err), ('', ''),
-            processutils.ProcessExecutionError(stderr=ret_err), ('', ''),
-            ('', ''),
-        ]
-
-        disk_utils.convert_image('source', 'dest', 'out_format')
-        convert_call = mock.call('qemu-img', 'convert', '-O',
-                                 'out_format', 'source', 'dest',
-                                 run_as_root=False,
-                                 prlimit=mock.ANY,
-                                 use_standard_locale=True)
-        execute_mock.assert_has_calls([
-            convert_call,
-            mock.call('sync'),
-            convert_call,
-            mock.call('sync'),
-            convert_call,
-        ])
-
     @mock.patch.object(os.path, 'getsize', autospec=True)
     @mock.patch.object(disk_utils, 'qemu_img_info', autospec=True)
     def test_get_image_mb(self, mock_qinfo, mock_getsize):
